==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/is.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Könnun á notkun",
    "Last report sent on: {on}" : "Síðasta skýrsla send þann: {on}",
    "An error occurred while sending your report." : "Villa kom upp við að senda skýrsluna þína.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Forritalisti <em>(fyrir hvert forrit: nafn, útgáfa, staða virkni)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Gagnagrunnsumhverfi <em>(tegund, útgáfa, stærð gagnagrunns)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Dulritunarupplýsingar <em>(er virkt?, hver er sjálfgefin kerfiseining)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Fjöldi sameigna <em>(eftir gerð og heimildum)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-umhverfi <em>(útgáfa, takmörk minnis, hám. keyrslutími, hám. skráastærð)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Nánar um ástand netþjóns <em>(útgáfa, notað skyndiminni, staða læsinga/forskoðunar/auðkennismynda)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Tölfræði <em>(fjöldi af: skrám, notendum, geymslur af hvaða gerð, athugasemdir og merki)</em>",
    "Help improve Nextcloud" : "Hjálpaðu til við að bæta Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Myndir þú vilja hjálpa til við að bæta Nextcloud með því að senda okkur ákveðin nafnlaus gögn um uppsetninguna þína og notkun? Þú getur gert þetta óvirkt aftur hvenær sem er í kerfisstjórnunarstillingunum.",
    "Not now" : "Ekki núna",
    "Send usage" : "Senda upplýsingar um notkun",
    "Never" : "Aldrei",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Þú getur hjálpað til við að bæta Nextcloud með því að senda okkur ákveðin gögn um uppsetninguna þína og notkun.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Við tökum gagnaleynd þína alvarlega. Sending notkunargagna er sjálfgefið óvirk og ef þú myndir velja að virkja hana, eru gögnin fyrst gerð algerlega órekjanleg og þér gefinn kostur á að velja hvað af þessum gögnum verður deilt. Þegar skýrsla berst er fyrri skýrsla fjarlægð. Sendu inn auða skýrslu til að hreinsa út öll gögn sem hafa verið geymd á þjóninum.",
    "Send new report now" : "Senda nýja skýrslu núna",
    "Send usage survey monthly" : "Senda mánaðarlega könnun á notkun",
    "Data to send" : "Gögn til sendingar",
    "Last report sent on: %s" : "Síðasta skýrsla send þann: %s",
    "Last report" : "Síðasta skýrsla",
    "Sent on: {on}" : "Sent þann: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Forritalisti <em>(fyrir hvert forrit: nafn, útgáfa, er virkjað?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Nánar um ástand netþjóns <em>(útgáfa, notað skyndiminni, virkni læsinga/forskoðunar/auðkennismynda)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Þú getur hjálpað til við að bæta Nextcloud með því að senda okkur ákveðin gögn um uppsetninguna þína og notkun.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Við tökum gagnaleynd þína alvarlega. Send gögn eru gerð algerlega órekjanleg og þú getur virkjað þetta eða gert óvirkt þegar þér sýnist, sjálfgefið er það óvirkt. Hér fyrir neðan er þér gefinn kostur á að velja hverju af þessum gögnum verður deilt og einnig séð síðustu skýrslu sem var send til okkar. Þegar ný skýrsla berst eru allar færslur úr fyrri skýrslu fjarlægðar. Ef þú gerir eina af stillingunum hér fyrir neðan, geturðu sent inn nýja skýrslu til að hreinsa út öll gögn sem hafa verið geymd á þjóninum.",
    "Sent on: %s" : "Sent þann: %s"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-14.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/is.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Könnun á notkun",
    "Last report sent on: {on}" : "Síðasta skýrsla send þann: {on}",
    "An error occurred while sending your report." : "Villa kom upp við að senda skýrsluna þína.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Forritalisti <em>(fyrir hvert forrit: nafn, útgáfa, staða virkni)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Gagnagrunnsumhverfi <em>(tegund, útgáfa, stærð gagnagrunns)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Dulritunarupplýsingar <em>(er virkt?, hver er sjálfgefin kerfiseining)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Fjöldi sameigna <em>(eftir gerð og heimildum)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-umhverfi <em>(útgáfa, takmörk minnis, hám. keyrslutími, hám. skráastærð)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Nánar um ástand netþjóns <em>(útgáfa, notað skyndiminni, staða læsinga/forskoðunar/auðkennismynda)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Tölfræði <em>(fjöldi skráa, notenda, geymslur af hvaða gerð, athugasemdir og merki)</em>",
    "Help improve Nextcloud" : "Hjálpaðu til við að bæta Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Myndir þú vilja hjálpa til við að bæta Nextcloud með því að senda okkur ákveðin nafnlaus gögn um uppsetninguna þína og notkun? Þú getur gert þetta óvirkt aftur hvenær sem er í kerfisstjórnunarstillingunum.",
    "Not now" : "Ekki núna",
    "Send usage" : "Senda upplýsingar um notkun",
    "Never" : "Aldrei",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Sendir nafnlaus gögn til Nextcloud til að hjálpa okkur við að bæta Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Sendir nafnlaus gögn til Nextcloud til að hjálpa okkur við að bæta Nextcloud.\n        Þú ert ávallt með fulla stjórn á hvaða efni sé sent til Nextcloud og getur\n        gert það óvirkt hvenær sem er.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Þú getur hjálpað til við að bæta Nextcloud með því að senda okkur ákveðin gögn um uppsetninguna þína og notkun.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Við tökum gagnaleynd þína alvarlega. Sending notkunargagna er sjálfgefið óvirk og ef þú myndir velja að virkja hana, eru gögnin fyrst gerð algerlega órekjanleg og þér gefinn kostur á að velja hvað af þessum gögnum verður deilt. Þegar skýrsla berst er fyrri skýrsla fjarlægð. Sendu inn auða skýrslu til að hreinsa út öll gögn sem hafa verið geymd á þjóninum.",
    "Send new report now" : "Senda nýja skýrslu núna",
    "Send usage survey monthly" : "Senda mánaðarlega könnun á notkun",
    "Data to send" : "Gögn til sendingar",
    "Last report sent on: %s" : "Síðasta skýrsla send þann: %s",
    "Last report" : "Síðasta skýrsla",
    "Sent on: {on}" : "Sent þann: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Forritalisti <em>(fyrir hvert forrit: nafn, útgáfa, er virkjað?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Nánar um ástand netþjóns <em>(útgáfa, notað skyndiminni, virkni læsinga/forskoðunar/auðkennismynda)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Tölfræði <em>(fjöldi af: skrám, notendum, geymslur af hvaða gerð, athugasemdir og merki)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Þú getur hjálpað til við að bæta Nextcloud með því að senda okkur ákveðin gögn um uppsetninguna þína og notkun.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Við tökum gagnaleynd þína alvarlega. Send gögn eru gerð algerlega órekjanleg og þú getur virkjað þetta eða gert óvirkt þegar þér sýnist, sjálfgefið er það óvirkt. Hér fyrir neðan er þér gefinn kostur á að velja hverju af þessum gögnum verður deilt og einnig séð síðustu skýrslu sem var send til okkar. Þegar ný skýrsla berst eru allar færslur úr fyrri skýrslu fjarlægðar. Ef þú gerir eina af stillingunum hér fyrir neðan, geturðu sent inn nýja skýrslu til að hreinsa út öll gögn sem hafa verið geymd á þjóninum.",
    "Sent on: %s" : "Sent þann: %s"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
